package org.expeditee.encryption.items;

public enum UserAppliedEncryptionPermission {
	none(0), homogeneous(1), hetrogeneous_limited(2), hetrogeneous(3), full(4);
	
	private final int val;
	
	private UserAppliedEncryptionPermission(int val) {
		this.val = val;
	}
	
	public static UserAppliedEncryptionPermission getPermission(
			String permissionCode, 
			UserAppliedEncryptionPermission defaultPermission) {
		if (permissionCode == null) {
			return defaultPermission;
		}
		
		permissionCode = permissionCode.trim().toLowerCase();
		if (permissionCode.length() == 0) {
			return defaultPermission;
		}
		
		try {
			return resolve(Integer.parseInt(permissionCode), defaultPermission);
		} catch (final NumberFormatException e) {
			try {
				return valueOf(permissionCode);
			} catch (final Exception ex) {
				return defaultPermission;
			}
		}
	}
	
	public int getCode() { return val; }
	
	public String toString() { return this.name(); }
	
	private static UserAppliedEncryptionPermission resolve(
			int val, 
			UserAppliedEncryptionPermission defaultPermission) {
		for (UserAppliedEncryptionPermission p : values()) {
			if (p.val == val) {
				return p;
			}
		}
		return defaultPermission;
	}
}
